<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="53"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>GUI per l&apos;applicazione di utili rifiniture</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>launches brightness-systray</source>
        <translation>lancia la luminosità del vassoio di sistema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>si apre con la scheda di visualizzazione aperta. Valido solo con il desktop Xfce in esecuzione</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Apre direttamente la scheda del tema. Valido su desktop Xfce e Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Display additional debug output in console</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Apre direttamente la scheda Altro. Valido su tutti i desktop</translation>
    </message>
</context>
<context>
    <name>Tweak</name>
    <message>
        <location filename="../tweak.ui" line="14"/>
        <location filename="../tweak.cpp" line="71"/>
        <location filename="../tweak.cpp" line="242"/>
        <location filename="../tweak.cpp" line="261"/>
        <source>MX Tweak</source>
        <translation>MX Rifiniture</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="33"/>
        <source>Xfce Panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="39"/>
        <location filename="../tweak.ui" line="233"/>
        <location filename="../tweak.ui" line="520"/>
        <location filename="../tweak.ui" line="599"/>
        <location filename="../tweak.ui" line="655"/>
        <location filename="../tweak.ui" line="682"/>
        <location filename="../tweak.ui" line="874"/>
        <location filename="../tweak.ui" line="1265"/>
        <location filename="../tweak.ui" line="1394"/>
        <location filename="../tweak.ui" line="1441"/>
        <location filename="../tweak.ui" line="1532"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="58"/>
        <source>Tasklist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="64"/>
        <source>Set Tasklist plugin to:</source>
        <translation>Imposta il plugin dell&apos;elenco attività su:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="71"/>
        <source>Docklike is the modern dock plugin for the panel. Window Buttons is the classic tasklist without dock features.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="78"/>
        <source>Tasklist Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="85"/>
        <source>Docklike Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="95"/>
        <source>Affects 1st Panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="101"/>
        <location filename="../tweak.ui" line="1048"/>
        <location filename="../tweak.ui" line="1158"/>
        <location filename="../tweak.ui" line="1285"/>
        <source>Placement</source>
        <translation>Posizionamento</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="114"/>
        <source>Backup/Restore Configuration (all panels)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="127"/>
        <source>Backup current panel configuration</source>
        <translation>Backup della configurazione attuale del pannello</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="141"/>
        <source>Restore selected panel configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="148"/>
        <source>Restore default panel</source>
        <translation>Ripristina il pannello di default </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="158"/>
        <source>Panel Plugin Scales</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="164"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="184"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Gestore energia</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="221"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="227"/>
        <source>Theme Options</source>
        <translation>Opzioni Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="262"/>
        <source>Remove User Theme Set</source>
        <translation>Rimuovi il set del tema utente</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="275"/>
        <source>Themes</source>
        <translation>Temi</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="281"/>
        <source>Application</source>
        <extracomment>theme an application will get</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="301"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="304"/>
        <source>Dark Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="311"/>
        <location filename="../tweak.ui" line="1778"/>
        <source>Window Manager</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>Gestore Finestre</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="331"/>
        <source>Legacy Styles</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="344"/>
        <source>Icons</source>
        <extracomment>icon theme</extracomment>
        <translation>Icone</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="351"/>
        <source>Cursors</source>
        <extracomment>cursor theme</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="358"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Salva le impostazioni correnti come set di un tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="368"/>
        <source>Size</source>
        <extracomment>size of the cursor</extracomment>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="378"/>
        <source>default</source>
        <extracomment>default cursor size determined by X server</extracomment>
        <translation>predefinito</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="401"/>
        <location filename="../tweak.ui" line="453"/>
        <source>Compositor</source>
        <translation>Compositore</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="413"/>
        <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="416"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="424"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="429"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="434"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="439"/>
        <location filename="../tweak.ui" line="1022"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>off</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="447"/>
        <source>Transparency and shadow options</source>
        <translation>Opzioni di trasparenza e ombreggiatura</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="463"/>
        <source>Xfce Compositor Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="466"/>
        <source>Xfwm Settings</source>
        <translation>Impostazioni di Xfwm</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="476"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Avvia lo strumento di configurazione compton-conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="479"/>
        <source>Picom settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="490"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Modifica compton.conf direttamente in un editor di testo </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="493"/>
        <source>Edit picom.conf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="540"/>
        <source>Display</source>
        <translation>Schermo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="546"/>
        <source>Display Tweaks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="552"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Retroilluminazione Hardware</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="575"/>
        <location filename="../tweak.ui" line="706"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="582"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>Valore di scala GTK</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="635"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Scegli lo schermo per le regolazioni con xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="645"/>
        <source>Resolution</source>
        <translation>Risoluzione</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="662"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>Valore di scala xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="689"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Software gestione luminosità (xrandr)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="713"/>
        <source>Saving is per display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="716"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="740"/>
        <source>Xfce</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="746"/>
        <source>Desktop</source>
        <translation>Scrivania</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="752"/>
        <source>Enable single-click on desktop</source>
        <translation>Abilita il click-singolo sul desktop</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="759"/>
        <source>Enable Desktop Zoom </source>
        <translation>Abilita lo zoom della scrivania</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="766"/>
        <location filename="../tweak.ui" line="1355"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Mostra le finestre di tutti gli spazi di lavoro nel pannello</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="773"/>
        <source>Do not shorten file names on the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="783"/>
        <source>Thunar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="789"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Abilita il click-singolo sul Gestore di File Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="796"/>
        <source>Reset custom right-click actions to system defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="803"/>
        <source>Thunar windows always open in split view</source>
        <translation>Le finestre di Thunar si aprono sempre in vista separata</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="810"/>
        <source>Thunar split view opens horizontal</source>
        <translation>La vista separata di Thunar si apre in orizzontale</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="820"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Mostra le percentuali nelle notifiche quando disponibili</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="827"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Mostra i pulsanti di azione del file di dialogo GTK nella parte inferiore delle finestre di dialogo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="834"/>
        <source>(also turns off Client Side Decorations for Xfce applications)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="844"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Abilita l&apos;ibernazione sul menu di chiusura</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="851"/>
        <source>note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="885"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="891"/>
        <location filename="../tweak.ui" line="1365"/>
        <source>Reset Defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="897"/>
        <source>Reset DefaultDock</source>
        <translation>Ripristina il Dock di default</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="904"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Ripristina il menu di Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="911"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Ripristina TUTTE le impostazioni di mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="918"/>
        <source>Add new default menu items, if any, to existing fluxbox menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="921"/>
        <source>Upgrade existing menu entries</source>
        <translation>Aggiorna le voci di menu esistenti</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="931"/>
        <source>Desktop Icons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="937"/>
        <source>Toggle desktop icons</source>
        <translation>Attiva/disattiva le icone della scrivania</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="945"/>
        <location filename="../tweak.ui" line="969"/>
        <source>On</source>
        <translation>Acceso</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="950"/>
        <location filename="../tweak.ui" line="974"/>
        <source>Off</source>
        <translation>Spento</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="958"/>
        <source>Toggle icon captions</source>
        <translation>Attiva/disattiva la descrizione delle icone</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="979"/>
        <source>On Hover</source>
        <translation>Al passaggio del mouse</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1006"/>
        <source>Screensaver</source>
        <translation>Salva Schermo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1012"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Tempo di inattività (minuti)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1035"/>
        <source>Toolbar Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1041"/>
        <source>Height</source>
        <translation>Altezza</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1122"/>
        <location filename="../tweak.ui" line="1232"/>
        <source>Autohide</source>
        <translation>Nascondi automaticamente</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1129"/>
        <source>Show Toolbar</source>
        <translation>Mostra la barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1136"/>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1152"/>
        <source>Dock Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1239"/>
        <source>Manage Tint2 Panel</source>
        <translation>Gestisci il pannello di Tint2</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1273"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1279"/>
        <source>Affects 1st panel</source>
        <translation>Agisce sul 1° pannello</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1296"/>
        <source>Bottom</source>
        <translation>in basso</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1301"/>
        <source>Left</source>
        <translation>a sinistra</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1306"/>
        <source>Top</source>
        <translation>in alto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1311"/>
        <source>Right</source>
        <translation>a destra</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1335"/>
        <source>Workspace</source>
        <translation>Spazio di lavoro</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1341"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1348"/>
        <source>Enable single-click</source>
        <translation>Abilita clic singolo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1371"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Ripristina i valori predefiniti di KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1405"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Tasto Super</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1411"/>
        <source>Also known as the &quot;windows&quot; key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1414"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Comando da eseguire col tasto Super (Meta)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1424"/>
        <source>xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1431"/>
        <source>Choose application</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1462"/>
        <source>Miscellaneous</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1518"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Reimposta Lightdm (shermata di login) al tema di default del sistema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1623"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Permetti il montaggio delle periferiche interne agli utenti non-root</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1616"/>
        <source>Enable kernel sandbox</source>
        <translation>Abilita la sandbox del kernel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1566"/>
        <source>requires reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1569"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1694"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1491"/>
        <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1494"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1630"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt installa pacchetti &quot;consiglia&quot; aggiuntivi come dipendenze</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1576"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Genera il menu Tutte le app di fluxbox dopo l&apos;installazione, la rimozione e gli aggiornamenti del pacchetto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1609"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Usa le decorazioni lato client (CSD) sulle applicazioni GTK3 che le supportano (richiede il riavvio della sessione)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1508"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>sospendere o rimuovere la sospensione sugli aggiornamenti dei kernel Liquorix</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1511"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Abilita gli aggiornamenti automatici del kernel Liquorix (repository MX ahs)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1684"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>sospendere o rimuovere la sospensione sugli aggiornamenti dei kernel Debian</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1687"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Abilita gli aggiornamenti automatici del kernel Debian</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1637"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Usa il driver Intel invece del driver di default &quot;modesetting&quot; (richiede il riavvio)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1471"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1583"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Usa l&apos;opzione tearfree amdgpu</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1545"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1525"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Usa l&apos;opzione driver tearfree radeon</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1501"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1559"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1552"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1647"/>
        <source>Password for administrative tasks:</source>
        <translation>Password per attività amministrative:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1654"/>
        <source>&amp;User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1661"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1701"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Init system that is used as the default on the main grub boot menu entry&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1704"/>
        <source>Change Default Init System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1729"/>
        <source>Xfce Settings</source>
        <translation>Impostazioni di Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1735"/>
        <source>Customize the panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1745"/>
        <source>Panel</source>
        <translation>Pannello</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1765"/>
        <source>Configure window behavior and shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1798"/>
        <source>Customize the look of your desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1811"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1823"/>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1833"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1891"/>
        <source>Quit application</source>
        <translation> Chiudi applicazione</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1894"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1900"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="72"/>
        <source>--display switch only valid for Xfce</source>
        <translation>cambio schermo valido solo per Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="241"/>
        <source>About MX Tweak</source>
        <translation>Informazioni su MX Rifiniture</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="243"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="244"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Applicazione per ritocchi e rapide modifiche ai temi predefiniti dell&apos;interfaccia </translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="246"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="247"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="261"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
</context>
<context>
    <name>TweakCompositor</name>
    <message>
        <location filename="../tweak_compositor.cpp" line="62"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="63"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositore Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="64"/>
        <source>Picom</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TweakMisc</name>
    <message>
        <location filename="../tweak_misc.cpp" line="305"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Inserisci un nome per il computer.</translation>
    </message>
    <message>
        <location filename="../tweak_misc.cpp" line="309"/>
        <source>Sorry, your computer name contains invalid characters.
You'll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Il nome del tuo computer contiene caratteri non validi.
Devi scegliere un nome differente
prima di procedere.</translation>
    </message>
</context>
<context>
    <name>TweakSuperKey</name>
    <message>
        <location filename="../tweak_superkey.cpp" line="43"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Seleziona l&apos;applicazione da eseguire</translation>
    </message>
</context>
<context>
    <name>TweakTheme</name>
    <message>
        <location filename="../tweak_theme.cpp" line="64"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="65"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="66"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="139"/>
        <source>Choose a theme set</source>
        <translation>Scegli un set di temi</translation>
    </message>
</context>
<context>
    <name>TweakXfcePanel</name>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="17"/>
        <source>Horizontal (Bottom)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="18"/>
        <source>Horizontal (Top)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="20"/>
        <source>Vertical (Left)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="21"/>
        <source>Vertical (Right)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="23"/>
        <source>docklike</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Pulsanti delle finestre</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="273"/>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <location filename="../tweak_xfce_panel.cpp" line="297"/>
        <location filename="../tweak_xfce_panel.cpp" line="301"/>
        <source>MX Tweak</source>
        <translation>MX Rifiniture</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>Plese remove special characters</source>
        <translation>Rimuovi i caratteri speciali</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>from file name</source>
        <translation>dal nome del file</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Il nome del file esiste già. Scegli un altro nome</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="298"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Il file non è un file archivio tar.xz valido</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="302"/>
        <source>Archive does not contain a panel config</source>
        <translation>L&apos;archivio non contiene un configuratore del pannello</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="733"/>
        <source>Panel Preferences</source>
        <translation>Preferenze del pannello</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>FinestraPrincipale</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="34"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="41"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software gestione luminosità (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="61"/>
        <location filename="../brightness_small.ui" line="89"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="68"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="75"/>
        <source>Hardware Backlight</source>
        <translation>Retroilluminazione Hardware</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="35"/>
        <source>Brightness</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>Display</source>
        <translation>Schermo</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="59"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Rimuovi il set del tema utente</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nuovo set di tema</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Inserisci il nome per il nuovo set di tema</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="38"/>
        <source>Window Buttons</source>
        <translation>Pulsanti delle finestre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="23"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="29"/>
        <source>Show button labels</source>
        <translation>Mostra le etichette dei pulsanti</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="36"/>
        <source>Show flat buttons</source>
        <translation>Usa pulsanti piatti</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="43"/>
        <source>Show handle</source>
        <translation>Mostra maniglie</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="50"/>
        <source>Sorting Order:</source>
        <translation>Ordinamento:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="58"/>
        <source>Timestamp</source>
        <translation>Timestamp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="63"/>
        <source>Group title and timestamp</source>
        <translation>Titolo del gruppo e timestamp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="68"/>
        <source>Window Title</source>
        <translation>Titolo della finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="73"/>
        <source>Group title and window title</source>
        <translation>Titolo del gruppo e della finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="78"/>
        <source>None, allow drag-and-drop</source>
        <translation>Nessuno, permetti drag&amp;drop</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="89"/>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="95"/>
        <source>Window grouping:</source>
        <translation>Raggruppa finestre:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="103"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="108"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="116"/>
        <source>Middle click action:</source>
        <translation>Azione del tasto centrale:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="124"/>
        <source>Nothing</source>
        <translation>Non fare niente</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="129"/>
        <source>Close window</source>
        <translation>Chiude la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="134"/>
        <source>Minimize window</source>
        <translation>Minimizza la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="142"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Ripristina le finestre minimizzate nello spazio di lavoro corrente</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="149"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Disegna la cornice della finestra quando il puntatore è sul suo pulsante</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="156"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Scorri tra le finestre usando la rotella del mouse</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="166"/>
        <source>Filtering</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="172"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Mostra le finestre di tutti gli spazi di lavoro o porzioni</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="179"/>
        <source>Show only minimized windows</source>
        <translation>Mostra solo le finestre minimizzate</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="186"/>
        <source>Show windows from all monitors</source>
        <translation>Mostra le finestre di tutti gli schermi</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="210"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="23"/>
        <source>Feature Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="29"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Visualizza direttamente a pieno schermo le finestre sovrapposte</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="36"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronizza il disegno allo spazio vuoto verticale</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="43"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Mostra l&apos;anteprima delle finestre al posto delle icone al passaggio</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="50"/>
        <source>Show shadows under popup windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre a comparsa</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="57"/>
        <source>Show shadows under dock windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre della barra dock</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="64"/>
        <source>Show shadows under regular windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre normali</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="74"/>
        <source>Opacity Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="80"/>
        <source>Window decorations</source>
        <translation>Decorazioni della finestra</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="103"/>
        <source>Inactive windows</source>
        <translation>Finestre inattive</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="126"/>
        <source>Windows during move</source>
        <translation>Finestre durante lo spostamento</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="149"/>
        <source>Windows during resize</source>
        <translation>Finestre durante il ridimensionamento</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="172"/>
        <source>Popup Windows</source>
        <translation>Finestre a comparsa</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="205"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="25"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Impostazioni del Compositore Xfwm </translation>
    </message>
</context>
</TS>